<?php
// src/OgBootBundle/Controller/OgBootController.php

namespace App\OgBootBundle\Controller;
require_once __DIR__ . '/../constants.php';
use OpenApi\Annotations as OA;
use Psr\Log\LoggerInterface;
use App\OgBootBundle\Service\CurlRequestService;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\JsonResponse;
use Exception;


class OgBootController
{
    private $logger;
    /**
     * @OA\Info(title="Ogboot API", version="1.0")
     */

    private $curlRequestService;

    public function __construct(CurlRequestService $curlRequestService, LoggerInterface $logger)
    {
        $this->curlRequestService = $curlRequestService;
        $this->logger = $logger;
    }

/*Tabla de Contenido
Obtener configuración de ogboot - GET /ogboot/config x
Obtener datos de rendimiento - GET /ogboot/status x
Mostrar información de todos los clientes ogLive instalados - GET /ogboot/oglives x 
Mostrar información de un cliente ogLive instalado - GET /ogboot/oglives/{Index|Dir} x
Mostrar información del cliente ogLive predeterminado - GET /ogboot/oglives/default x
Cambiar ogLive predeterminado - POST /ogboot/oglives/default/{Index} x 
Instalar nuevo cliente ogLive desde imagen descargada - POST /ogboot/oglive/{Index/iso} ----
Desinstalar cliente ogLive y eliminar imagen - DELETE /ogboot/oglives/{Index/iso} -------
Regenerar archivo de información de los ogLive - PUT /ogboot/oglives
Mostrar menú de descarga de imagen de ogLive - GET /ogboot/images/download X 

/////////////////////////////////////////////

Obtener todos los archivos de arranque - GET /ogboot/pxes
Obtener archivo de arranque - GET /ogboot/clients/pxes/{mac}
Crear archivo de arranque - POST /ogboot/pxes
Eliminar archivo de arranque - DELETE /ogboot/clients/pxes
Obtener todas las plantillas - GET /ogboot/pxe-templates
Obtener contenido de la plantilla - GET /ogboot/pxe-templates/{nombre}
Crear plantilla - POST /ogboot/pxe-templates
Regenerar plantilla - PUT /ogboot/pxe-templates
*/

    /**
    * @Route("/ogboot/help", name="help", methods={"GET"})
    */
    public function help(): Response
    {

        # $result = $this->curlRequestService->common_request(OG_REST_CMD_POWEROFF, POST, [OG_REST_PARAM_CLIENTS => $ips]);
        $result = $this->curlRequestService->callOgLive("help");

        if ($result) {
            return new Response($result, Response::HTTP_OK);
        } else {
            return new Response('Failed', Response::HTTP_INTERNAL_SERVER_ERROR);
        }
    }

/**
 * @Route("/ogboot/config", name="config", methods={"GET"})
 * @OA\Get(
 *     path="/ogboot/config",
 *     summary="Get ogboot configuration",
 *     @OA\Response(
 *         response=200,
 *         description="Successful operation",
 *         @OA\JsonContent(
 *             type="object",
 *             @OA\Property(
 *                 property="config-file",
 *                 type="string",
 *                 description="Configuration file path"
 *             ),
 *             @OA\Property(
 *                 property="download-url",
 *                 type="string",
 *                 description="ogLive download URL"
 *             ),
 *             @OA\Property(
 *                 property="download-dir",
 *                 type="string",
 *                 description="ogLive download directory"
 *             ),
 *             @OA\Property(
 *                 property="install-dir",
 *                 type="string",
 *                 description="ogLive installation directory"
 *             ),
 *             @OA\Property(
 *                 property="default-name",
 *                 type="string",
 *                 description="Default ogLive name"
 *             ),
 *             @OA\Property(
 *                 property="min-release",
 *                 type="string",
 *                 description="Minimum compatibility release"
 *             )
 *         )
 *     ),
 *     @OA\Response(
 *         response=500,
 *         description="Failed to retrieve configuration"
 *     )
 * )
 */
    public function config(): Response
    {

        # $result = $this->curlRequestService->common_request(OG_REST_CMD_POWEROFF, POST, [OG_REST_PARAM_CLIENTS => $ips]);
        $result = $this->curlRequestService->callOgLive("config");

        if ($result) {
            return new Response($result, Response::HTTP_OK);
        } else {
            return new Response('Failed', Response::HTTP_INTERNAL_SERVER_ERROR);
        }
    }

/**
 * @Route("/ogboot/status", name="status", methods={"GET"})
 * @OA\Get(
 *     path="/ogboot/status",
 *     summary="Get ogboot status",
 *     @OA\Response(
 *         response=200,
 *         description="Successful operation",
 *         @OA\JsonContent(
 *             type="object",
 *             @OA\Property(
 *                 property="message",
 *                 type="string",
 *                 description="Status message indicating any issues detected"
 *             )
 *         )
 *     ),
 *     @OA\Response(
 *         response=500,
 *         description="Failed to retrieve status"
 *     )
 * )
 */
    public function status(): Response
    {

        # $result = $this->curlRequestService->common_request(OG_REST_CMD_POWEROFF, POST, [OG_REST_PARAM_CLIENTS => $ips]);
        $result = $this->curlRequestService->callOgLive("check");

        if ($result) {
            return new Response($result, Response::HTTP_OK);
        } else {
            return new Response('Failed', Response::HTTP_INTERNAL_SERVER_ERROR);
        }
    }

/**
 * @Route("/ogboot/oglives", name="getOglives", methods={"GET"})
 * @OA\Get(
 *     path="/ogboot/oglives",
 *     summary="Get information of all installed ogLive clients",
 *     @OA\Response(
 *         response=200,
 *         description="Successful operation",
 *         @OA\JsonContent(
 *             type="array",
 *             @OA\Items(
 *                 type="object",
 *                 @OA\Property(
 *                     property="distribution",
 *                     type="string",
 *                     description="Distribution name of the ogLive client"
 *                 ),
 *                 @OA\Property(
 *                     property="kernel",
 *                     type="string",
 *                     description="Kernel version of the ogLive client"
 *                 ),
 *                 @OA\Property(
 *                     property="architecture",
 *                     type="string",
 *                     description="Architecture of the ogLive client"
 *                 ),
 *                 @OA\Property(
 *                     property="revision",
 *                     type="string",
 *                     description="Revision of the ogLive client"
 *                 ),
 *                 @OA\Property(
 *                     property="directory",
 *                     type="string",
 *                     description="Directory name of the ogLive client"
 *                 ),
 *                 @OA\Property(
 *                     property="iso",
 *                     type="string",
 *                     description="ISO file name of the ogLive client"
 *                 )
 *             )
 *         )
 *     ),
 *     @OA\Response(
 *         response=500,
 *         description="Failed to retrieve information of installed ogLive clients"
 *     )
 * )
 */
    public function getOglives(): Response
    {

        # $result = $this->curlRequestService->common_request(OG_REST_CMD_POWEROFF, POST, [OG_REST_PARAM_CLIENTS => $ips]);
        $result = $this->curlRequestService->callOgLive("show all");

        if ($result) {
            return new Response($result, Response::HTTP_OK);
        } else {
            return new Response('Failed', Response::HTTP_INTERNAL_SERVER_ERROR);
        }
    }

/**
 * @Route("/ogboot/oglives/default", name="getOgliveDefault", methods={"GET"})
 * @OA\Get(
 *     path="/ogboot/oglives/default",
 *     summary="Get information of the default ogLive client",
 *     @OA\Response(
 *         response=200,
 *         description="Successful operation",
 *         @OA\JsonContent(
 *             type="object",
 *             @OA\Property(
 *                 property="distribution",
 *                 type="string",
 *                 description="Distribution name of the default ogLive client"
 *             ),
 *             @OA\Property(
 *                 property="kernel",
 *                 type="string",
 *                 description="Kernel version of the default ogLive client"
 *             ),
 *             @OA\Property(
 *                 property="architecture",
 *                 type="string",
 *                 description="Architecture of the default ogLive client"
 *             ),
 *             @OA\Property(
 *                 property="revision",
 *                 type="string",
 *                 description="Revision of the default ogLive client"
 *             ),
 *             @OA\Property(
 *                 property="directory",
 *                 type="string",
 *                 description="Directory name of the default ogLive client"
 *             ),
 *             @OA\Property(
 *                 property="iso",
 *                 type="string",
 *                 description="ISO file name of the default ogLive client"
 *             )
 *         )
 *     ),
 *     @OA\Response(
 *         response=500,
 *         description="Failed to retrieve information of the default ogLive client"
 *     )
 * )
 */

    public function getOgliveDefault(Request $request): Response
    {
        # $result = $this->curlRequestService->common_request(OG_REST_CMD_POWEROFF, POST, [OG_REST_PARAM_CLIENTS => $ips]);
        $result = $this->curlRequestService->callOgLive("show default");

        if ($result) {
            return new Response($result, Response::HTTP_OK);
        } else {
            return new Response('Failed', Response::HTTP_INTERNAL_SERVER_ERROR);
        }
    }

/**
 * @Route("/ogboot/oglives/{id}", name="getOglive", methods={"GET"})
 * @OA\Get(
 *     path="/ogboot/oglives/{id}",
 *     summary="Get information of an installed ogLive client",
 *     @OA\Parameter(
 *         name="id",
 *         in="path",
 *         description="Index or Directory of the installed ogLive client",
 *         required=true,
 *         @OA\Schema(
 *             type="string"
 *         )
 *     ),
 *     @OA\Response(
 *         response=200,
 *         description="Successful operation",
 *         @OA\JsonContent(
 *             type="object",
 *             @OA\Property(
 *                 property="distribution",
 *                 type="string",
 *                 description="Distribution name of the installed ogLive client"
 *             ),
 *             @OA\Property(
 *                 property="kernel",
 *                 type="string",
 *                 description="Kernel version of the installed ogLive client"
 *             ),
 *             @OA\Property(
 *                 property="architecture",
 *                 type="string",
 *                 description="Architecture of the installed ogLive client"
 *             ),
 *             @OA\Property(
 *                 property="revision",
 *                 type="string",
 *                 description="Revision of the installed ogLive client"
 *             ),
 *             @OA\Property(
 *                 property="directory",
 *                 type="string",
 *                 description="Directory name of the installed ogLive client"
 *             ),
 *             @OA\Property(
 *                 property="iso",
 *                 type="string",
 *                 description="ISO file name of the installed ogLive client"
 *             )
 *         )
 *     ),
 *     @OA\Response(
 *         response=404,
 *         description="ogLive client not found"
 *     )
 * )
 */

    public function getOglive(Request $request): Response
    {
        $id = (int) $request->get('id');
        # $result = $this->curlRequestService->common_request(OG_REST_CMD_POWEROFF, POST, [OG_REST_PARAM_CLIENTS => $ips]);
        $result = $this->curlRequestService->callOgLive("show $id");

        if ($result) {
            return new Response($result, Response::HTTP_OK);
        } else {
            return new Response('Failed', Response::HTTP_INTERNAL_SERVER_ERROR);
        }
    }

/**
 * @Route("/ogboot/oglives/default/{id}", name="setOgliveDefault", methods={"POST"})
 * @OA\Post(
 *     path="/ogboot/oglives/default/{id}",
 *     summary="Change default ogLive",
 *     @OA\Parameter(
 *         name="id",
 *         in="path",
 *         description="Index of the ogLive client to set as default",
 *         required=true,
 *         @OA\Schema(
 *             type="string"
 *         )
 *     ),
 *     @OA\Response(
 *         response=200,
 *         description="Default ogLive changed successfully",
 *         @OA\JsonContent(
 *             type="object",
 *             @OA\Property(property="success", type="string")
 *         )
 *     ),
 *     @OA\Response(
 *         response=404,
 *         description="ogLive client not found"
 *     )
 * )
 */

    public function setOgliveDefault(Request $request): Response
    {
        $id = (int) $request->get('id');
        # $result = $this->curlRequestService->common_request(OG_REST_CMD_POWEROFF, POST, [OG_REST_PARAM_CLIENTS => $ips]);
        $result = $this->curlRequestService->callOgLive("set-default $id");

        if ($result) {
            return new Response($result, Response::HTTP_OK);
        } else {
            return new Response('Failed', Response::HTTP_INTERNAL_SERVER_ERROR);
        }
    }


    //Mostrar menú de descarga de imagen de ogLive - GET /ogboot/images/download

/**
 * @Route("/ogboot/images/download", name="getDownloadMenu", methods={"GET"})
 * @OA\Get(
 *     path="/ogboot/images/download",
 *     summary="Get available ISO images for download",
 *     @OA\Response(
 *         response=200,
 *         description="List of available ISO images",
 *         @OA\JsonContent(
 *             type="array",
 *             @OA\Items(
 *                 type="object",
 *                 @OA\Property(property="id", type="string"),
 *                 @OA\Property(property="filename", type="string"),
 *                 @OA\Property(property="installed", type="boolean"),
 *                 @OA\Property(property="compatible", type="boolean")
 *             )
 *         )
 *     )
 * )
 */

    public function getDownloadMenu(): Response
    {
        // Ejecutar el comando "oglivecli download" y obtener la salida
        $downloadsOutput = $this->curlRequestService->callOgLive("download");

        // Separar la salida por líneas
        $downloads = explode("\n", trim($downloadsOutput));
        $result = [];
        
        foreach ($downloads as $download) {
            // Define el patrón de la expresión regular
            $pattern = '/^(\d+)\) (\(\*\))?\s?(\(\+\))?\s?(.+\.iso)$/';
        
            // Realiza el matcheo de la línea con el patrón
            preg_match($pattern, $download, $matches);
        
            // Si hay coincidencias, extrae la información
            if (!empty($matches)) {
                $id = $matches[1];
                $installed = !empty($matches[2]);
                $compatible = !empty($matches[3]);
                $filename = $matches[4];
        
                // Agrega la información al resultado
                $result[] = [
                    'id' => $id,
                    'filename' => $filename,
                    'installed' => $installed,
                    'compatible' => $compatible
                ];
            }
        }

        // Convertir el array de downloads a JSON
        $jsonDownloads = json_encode($result);

        // Crear una respuesta JSON y devolverla
        return new Response($jsonDownloads, Response::HTTP_OK, [
            'Content-Type' => 'application/json'
        ]);
    }

/**
 * @Route("/ogboot/oglives/{id}", name="installOglive", methods={"POST"})
 * @OA\Post(
 *     path="/ogboot/oglives/{id}",
 *     summary="Install an ogLive client",
 *     @OA\Parameter(
 *         name="id",
 *         in="path",
 *         description="ID of the ogLive client to install",
 *         required=true,
 *         @OA\Schema(
 *             type="integer"
 *         )
 *     ),
 *     @OA\Response(
 *         response=200,
 *         description="ogLive client installed successfully",
 *         @OA\JsonContent(
 *             type="object",
 *             @OA\Property(property="message", type="string")
 *         )
 *     ),
 *     @OA\Response(
 *         response=500,
 *         description="Failed to install ogLive client",
 *         @OA\JsonContent(
 *             type="object",
 *             @OA\Property(property="error", type="string")
 *         )
 *     )
 * )
 */
    public function installOglive(Request $request): Response
    {
        $id = (int) $request->get('id');
        # $result = $this->curlRequestService->common_request(OG_REST_CMD_POWEROFF, POST, [OG_REST_PARAM_CLIENTS => $ips]);
        $result = $this->curlRequestService->callOgLive("download $id");

        if ($result) {
            return new Response($result, Response::HTTP_OK);
        } else {
            return new Response('Failed', Response::HTTP_INTERNAL_SERVER_ERROR);
        }
    }

/**
 * @Route("/ogboot/oglives/{id}", name="uninstallOglive", methods={"DELETE"})
 * @OA\Delete(
 *     path="/ogboot/oglives/{id}",
 *     summary="Uninstall an ogLive client",
 *     @OA\Parameter(
 *         name="id",
 *         in="path",
 *         description="ID of the ogLive client to uninstall",
 *         required=true,
 *         @OA\Schema(
 *             type="integer"
 *         )
 *     ),
 *     @OA\Response(
 *         response=200,
 *         description="ogLive client uninstalled successfully",
 *         @OA\JsonContent(
 *             type="object",
 *             @OA\Property(property="message", type="string")
 *         )
 *     ),
 *     @OA\Response(
 *         response=500,
 *         description="Failed to uninstall ogLive client",
 *         @OA\JsonContent(
 *             type="object",
 *             @OA\Property(property="error", type="string")
 *         )
 *     )
 * )
 */

    public function uninstallOglive(Request $request): Response
    {
        $id = (int) $request->get('id');
        # $result = $this->curlRequestService->common_request(OG_REST_CMD_POWEROFF, POST, [OG_REST_PARAM_CLIENTS => $ips]);
        $result = $this->curlRequestService->callOgLive("uninstall $id");

        if ($result) {
            return new Response($result, Response::HTTP_OK);
        } else {
            return new Response('Failed', Response::HTTP_INTERNAL_SERVER_ERROR);
        }
    }


/**
 * @Route("/ogboot/v1/pxes", name="config", methods={"GET"})
 * @OA\Get(
 *     path="/ogboot/v1/pxes",
 *     summary="Get ogboot configuration",
 *     @OA\Response(
 *         response=200,
 *         description="Successful operation",
 *         @OA\JsonContent(
 *             type="object",
 *             @OA\Property(
 *                 property="config-file",
 *                 type="string",
 *                 description="Configuration file path"
 *             ),
 *             @OA\Property(
 *                 property="download-url",
 *                 type="string",
 *                 description="ogLive download URL"
 *             ),
 *             @OA\Property(
 *                 property="download-dir",
 *                 type="string",
 *                 description="ogLive download directory"
 *             ),
 *             @OA\Property(
 *                 property="install-dir",
 *                 type="string",
 *                 description="ogLive installation directory"
 *             ),
 *             @OA\Property(
 *                 property="default-name",
 *                 type="string",
 *                 description="Default ogLive name"
 *             ),
 *             @OA\Property(
 *                 property="min-release",
 *                 type="string",
 *                 description="Minimum compatibility release"
 *             )
 *         )
 *     ),
 *     @OA\Response(
 *         response=500,
 *         description="Failed to retrieve configuration"
 *     )
 * )
 */
public function getBootFiles(): JsonResponse
{
    // Ruta donde están alojados los archivos de arranque
    $directory = '/opt/ogboot/tftpboot/ipxe_scripts';

    // Escanea el directorio y obtiene la lista de archivos de arranque
    $files = scandir($directory);

    // Filtra los archivos que no son directorios ni archivos ocultos
    $bootFiles = array_filter($files, function ($file) {
        return !in_array($file, ['.', '..', '.gitkeep']) && !is_dir($file);
    });

    // Construye la respuesta JSON con la lista de archivos de arranque
    $response = [
        'boot_files' => array_values($bootFiles)
    ];

    // Devuelve la respuesta JSON
    return new JsonResponse($response, Response::HTTP_OK);
}

    /**
     * @Route("/ogboot/v1/pxes/{mac}", name="ogboot_boot_file", methods={"GET"})
     */
    public function getBootFile(string $mac): Response
    {
        // Ruta donde están alojados los archivos de arranque
        $directory = '/opt/ogboot/tftpboot/ipxe_scripts';

        // Genera el nombre del archivo basado en la dirección MAC
        $fileName = "01-" . $mac;

        // Path completo del archivo
        $filePath = "$directory/$fileName";

        // Verifica si el archivo existe
        if (!file_exists($filePath)) {
            // Devuelve una respuesta 404 si no se encuentra el archivo de arranque
            return new Response(null, Response::HTTP_NOT_FOUND);
        }

        // Lee el contenido del archivo
        $content = file_get_contents($filePath);

        // Devuelve el contenido del archivo como texto plano
        return new Response($content, Response::HTTP_OK, ['Content-Type' => 'text/plain']);
    }


    /**
     * @Route("/ogboot/v1/pxes", name="ogboot_create_boot_file", methods={"POST"})
     */
    public function createBootFile(Request $request): Response
    {
        // Obtener los datos del cuerpo de la solicitud
        $requestData = json_decode($request->getContent(), true);

        // Verificar si los datos necesarios están presentes en la solicitud
        if (!isset($requestData['mac']) || !isset($requestData['config'])) {
            return new JsonResponse(['error' => 'Los datos de la solicitud son incorrectos'], Response::HTTP_BAD_REQUEST);
        }

        // Directorio donde se almacenarán los archivos de arranque
        $directory = '/opt/ogboot/tftpboot/ipxe_scripts';

        // Generar el nombre del archivo basado en la dirección MAC
        $fileName = "01-" . str_replace(':', '-', $requestData['mac']);

        // Ruta completa del archivo
        $filePath = "$directory/$fileName";

        // Contenido del archivo de arranque
        $fileContent = $requestData['config'];

        // Intentar crear el archivo de arranque
        if (file_put_contents($filePath, $fileContent) === false) {
            // Devolver un error si no se puede crear el archivo
            return new JsonResponse(['error' => 'Error al crear el archivo de arranque'], Response::HTTP_INTERNAL_SERVER_ERROR);
        }

        // Devolver una respuesta de éxito si el archivo se creó correctamente
        return new JsonResponse(['message' => 'El archivo de arranque se creó exitosamente'], Response::HTTP_OK);
    }

    /**
     * @Route("/ogboot/v1/pxes/{mac}", name="ogboot_delete_boot_file", methods={"DELETE"})
     */
    public function deleteBootFile(string $mac): Response
    {
        // Directorio donde están almacenados los archivos de arranque
        $directory = '/opt/ogboot/tftpboot/ipxe_scripts';

        // Generar el nombre del archivo basado en la dirección MAC
        $fileName = "01-" . str_replace(':', '-', $mac);

        // Ruta completa del archivo
        $filePath = "$directory/$fileName";

        // Verificar si el archivo existe
        if (!file_exists($filePath)) {
            // Devolver un error 404 si el archivo no se encuentra
            return new JsonResponse(['error' => 'No se encontró ningún archivo de arranque con la dirección MAC especificada'], Response::HTTP_NOT_FOUND);
        }

        // Intentar eliminar el archivo de arranque
        if (!unlink($filePath)) {
            // Devolver un error 500 si no se puede eliminar el archivo
            return new JsonResponse(['error' => 'Error al eliminar el archivo de arranque'], Response::HTTP_INTERNAL_SERVER_ERROR);
        }

        // Devolver una respuesta de éxito si el archivo se eliminó correctamente
        return new JsonResponse(['message' => 'El archivo de arranque se eliminó correctamente'], Response::HTTP_OK);
    }

    /**
     * @Route("", methods={"POST"})
     * 
     * @OA\Post(
     *     path="/ogboot/v1/pxe-templates",
     *     summary="Crear Plantilla",
     *     description="Crea una nueva plantilla de arranque utilizando los datos proporcionados.",
     *     @OA\RequestBody(
     *         required=true,
     *         @OA\JsonContent(
     *             type="object",
     *             @OA\Property(property="name_template", type="string", example="mi_plantilla.ipxe"),
     *             @OA\Property(property="content_template", type="string", example="#!ipxe\nset timeout 0\nset timeout-style hidden\n\nset ISODIR ogLive\nset default 0\nset kernelargs INFOHOST\ntime kernel tftp://172.17.8.71/ogLive/ogvmlinuz ${kernelargs}\ntime initrd tftp://172.17.8.71/ogLive/oginitrd.img\nboot")
     *         )
     *     ),
     *     @OA\Response(
     *         response=200,
     *         description="La plantilla de arranque se creó exitosamente.",
     *         @OA\JsonContent(
     *             type="object",
     *             @OA\Property(property="message", type="string", example="Plantilla creada exitosamente."),
     *             @OA\Property(property="template", type="string", example="#!ipxe\nset timeout 0\nset timeout-style hidden\n\nset ISODIR ogLive\nset default 0\nset kernelargs INFOHOST\ntime kernel tftp://172.17.8.71/ogLive/ogvmlinuz ${kernelargs}\ntime initrd tftp://172.17.8.71/ogLive/oginitrd.img\nboot")
     *         )
     *     ),
     *     @OA\Response(
     *         response=400,
     *         description="La solicitud no pudo ser procesada debido a un error en los datos proporcionados en el cuerpo de la solicitud."
     *     ),
     *     @OA\Response(
     *         response=500,
     *         description="Ocurrió un error al crear la plantilla de arranque."
     *     )
     * )
     */
    public function createTemplate(Request $request)
    {
        $data = json_decode($request->getContent(), true);

        if (!isset($data['name_template']) || !isset($data['content_template'])) {
            return new Response('La solicitud no pudo ser procesada debido a un error en los datos proporcionados en el cuerpo de la solicitud.', 400);
        }

        $nameTemplate = $data['name_template'];
        $contentTemplate = $data['content_template'];
        $templateDir = '/opt/ogboot/tftpboot/ipxe_scripts/templates';

        // Validar nombre del archivo
        if (!preg_match('/^[a-zA-Z0-9._-]+$/', $nameTemplate)) {
            return new Response('Nombre de la plantilla no válido.', 400);
        }

        // Crear la ruta completa del archivo
        $filePath = $templateDir . '/' . $nameTemplate;

        try {
            file_put_contents($filePath, $contentTemplate);
        } catch (\Exception $e) {
            return new Response('Ocurrió un error al crear la plantilla de arranque.', 500);
        }

        return new Response(json_encode([
            'message' => 'Plantilla creada exitosamente.',
            'template' => $contentTemplate
        ]), 200, ['Content-Type' => 'application/json']);
    }


   /**
     * @Route("/{name}", methods={"DELETE"})
     * 
     * @OA\Delete(
     *     path="/ogboot/v1/pxe-templates/{name}",
     *     summary="Eliminar Plantilla",
     *     description="Elimina una plantilla de arranque específica utilizando su nombre.",
     *     @OA\Parameter(
     *         name="name",
     *         in="path",
     *         required=true,
     *         description="El nombre de la plantilla de arranque que se desea eliminar.",
     *         @OA\Schema(type="string")
     *     ),
     *     @OA\Response(
     *         response=200,
     *         description="La plantilla de arranque se eliminó correctamente.",
     *         @OA\JsonContent(
     *             type="object",
     *             @OA\Property(property="message", type="string", example="Plantilla eliminada correctamente.")
     *         )
     *     ),
     *     @OA\Response(
     *         response=404,
     *         description="No se encontró ninguna plantilla de arranque con el nombre especificado."
     *     ),
     *     @OA\Response(
     *         response=500,
     *         description="Ocurrió un error al eliminar la plantilla de arranque."
     *     )
     * )
     */
    public function deleteTemplate($name)
    {
        $templateDir = '/opt/ogboot/tftpboot/ipxe_scripts/templates';
        $filePath = $templateDir . '/' . $name;

        if (!file_exists($filePath)) {
            return new Response('No se encontró ninguna plantilla de arranque con el nombre especificado.', 404);
        }

        try {
            unlink($filePath);
        } catch (\Exception $e) {
            return new Response('Ocurrió un error al eliminar la plantilla de arranque.', 500);
        }

        return new Response(json_encode([
            'message' => 'Plantilla eliminada correctamente.'
        ]), 200, ['Content-Type' => 'application/json']);
    }


}
